Welcome to Ansys Templates
==========================
|pyansys| |python| |pypi| |GH-CI| |codecov| |MIT| |black|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/badge/Python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue
   :target: https://pypi.org/project/ansys-templates/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-templates.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-templates/
   :alt: PyPI

.. |codecov| image:: https://codecov.io/gh/pyansys/ansys-templates/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/pyansys/ansys-templates
   :alt: Codecov

.. |GH-CI| image:: https://github.com/pyansys/ansys-templates/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/pyansys/ansys-templates/actions/workflows/ci.yml
   :alt: CH-CI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black


The ``ansys-templates`` repository holds a collection of useful templates compliant
with PyAnsys guidelines. It also provides the ``ansys-templates`` command line tool
for interactively generating new projects based on previous templates.

The main advantages of using this tool are:

- Building process is fully interactive. There is no need to manually modify files.
- Output of the project can easily be customized during the rendering process.
- Generated projects are compliant with `PyAnsys Developer's Guidelines`_.

.. _PyAnsys Developer's Guidelines: https://dev.docs.pyansys.com/

For information on using this tool, see the `Ansys Templates Documentation`_.

.. _Ansys Templates Documentation: https://templates.pyansys.com/ 


Rendered Templates Demos
------------------------

To have a better idea on how each template will look once it gets rendered,
please refer to its demo branch:

* Rendered example for `pybasic template`_
* Rendered example for `pyansys template`_
* Rendered example for `pyansys-advanced-flit template`_
* Rendered example for `pyansys-advanced-poetry template`_
* Rendered example for `pyansys-advanced-setuptools template`_
* Rendered example for `pyace-fast template`_
* Rendered example for `pyace-flask template`_
* Rendered example for `pyace-grpc template`_
* Rendered example for `pyace-pkg template`_

.. _pybasic template: https://github.com/pyansys/ansys-templates/tree/demo/pybasic
.. _pyansys template: https://github.com/pyansys/ansys-templates/tree/demo/pyansys
.. _pyansys-advanced-flit template: https://github.com/pyansys/ansys-templates/tree/demo/pyansys-advanced-flit
.. _pyansys-advanced-poetry template: https://github.com/pyansys/ansys-templates/tree/demo/pyansys-advanced-poetry
.. _pyansys-advanced-setuptools template: https://github.com/pyansys/ansys-templates/tree/demo/pyansys-advanced-setuptools
.. _pyace-fast template: https://github.com/pyansys/ansys-templates/tree/demo/pyace-fast
.. _pyace-flask template: https://github.com/pyansys/ansys-templates/tree/demo/pyace-flask
.. _pyace-grpc template: https://github.com/pyansys/ansys-templates/tree/demo/pyace-grpc
.. _pyace-pkg template: https://github.com/pyansys/ansys-templates/tree/demo/pyace-pkg
